@@ -1,5 +1,5 @@
 # encoding: utf-8
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function, unicode_literals
 
 from django.core.exceptions import ValidationError
 from django.db import models
